@@ -3,11 +3,15 @@ Module for Serialization and Deserialization of KNX Routing Indications.
 
 Routing indications are used to transport CEMI Messages.
 """
+import logging
+
 from xknx.exceptions import UnsupportedCEMIMessage
 
 from .body import KNXIPBody
 from .cemi_frame import CEMIFrame
-from .knxip_enum import KNXIPServiceType
+from .knxip_enum import CEMIMessageCode, KNXIPServiceType
+
+logger = logging.getLogger("xknx.log")
 
 
 class RoutingIndication(KNXIPBody):
@@ -17,10 +21,14 @@ class RoutingIndication(KNXIPBody):
 
     service_type = KNXIPServiceType.ROUTING_INDICATION
 
-    def __init__(self, xknx):
+    def __init__(self, xknx, cemi: CEMIFrame = None):
         """Initialize SearchRequest object."""
         super().__init__(xknx)
-        self.cemi = CEMIFrame(xknx)
+        self.cemi = (
+            cemi
+            if cemi is not None
+            else CEMIFrame(xknx, code=CEMIMessageCode.L_DATA_IND)
+        )
 
     def calculated_length(self):
         """Get length of KNX/IP body."""
@@ -31,7 +39,7 @@ class RoutingIndication(KNXIPBody):
         try:
             return self.cemi.from_knx(raw)
         except UnsupportedCEMIMessage as unsupported_cemi_err:
-            self.xknx.logger.warning("CEMI not supported: %s", unsupported_cemi_err)
+            logger.warning("CEMI not supported: %s", unsupported_cemi_err)
             self.cemi = None
             return len(raw)
 
